%global codename fuerte
%global shortname laser_pipeline

Name:		ros-%{codename}-laser-pipeline
Version:	1.4.4
Release:	1%{?dist}
Summary:	ROS libraries for processing laser data
License:	BSD
URL:		http://ros.org/wiki/laser_pipeline
Source0:	https://code.ros.org/svn/release/download/stacks/laser_pipeline/laser_pipeline-%{version}/laser_pipeline-%{version}.tar.bz2
# common_rosdeps is obsolete
Patch0:		ros-laser-pipeline-nocr.patch
BuildRequires:	ros-%{codename}-ros-devel, ros-%{codename}-ros-comm-devel
BuildRequires:	ros-%{codename}-pluginlib-devel, ros-%{codename}-common-msgs-devel
BuildRequires:	ros-%{codename}-filters-devel, ros-%{codename}-geometry-devel
BuildRequires:	ros-%{codename}-perception-pcl-devel
BuildRequires:	cmake, python-yaml, eigen3-devel
BuildRequires:	chrpath
Provides:	ros-%{shortname} = %{version}-%{release}
Provides:	ros-laser-pipeline = %{version}-%{release}

%description
ROS Libraries for processing laser data, including converting laser data into 
3D representations.

%package devel
Summary:	Development files for ROS laser_pipeline
Requires:	ros-%{codename}-ros-devel, ros-%{codename}-ros-comm-devel
Requires:	ros-%{codename}-pluginlib-devel, ros-%{codename}-common-msgs-devel
Requires:	ros-%{codename}-filters-devel, ros-%{codename}-geometry-devel
Requires:	ros-%{codename}-perception-pcl-devel
Requires:	%{name} = %{version}-%{release}
Provides:	ros-%{shortname}-devel = %{version}-%{release}
Provides:	ros-laser-pipeline-devel = %{version}-%{release}

%description devel
Development files for ROS laser_pipeline.

%prep
%setup -q -c
# We have to do this so the cmake gunk can find itself. So idiotic.
mv %{shortname}-%{version} %{shortname}
%patch0 -p1 -b .nocr

%build
cd %{shortname}
source /etc/catkin/profile.d/10.ros.all
export ROS_PACKAGE_PATH="%{_builddir}/%{name}-%{version}:$ROS_PACKAGE_PATH"
for i in laser_geometry laser_assembler laser_filters; do
  pushd $i
  mkdir build
  cd build
  %cmake -DSETUPTOOLS_DEB_LAYOUT=OFF ..
  make %{?_smp_mflags}
  popd
done

%install
cd %{shortname}
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/
cp -a stack.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/

#laser_assembler
pushd laser_assembler
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/laser_assembler
cp -a include *.dox *.xml doc srv srv_gen %{buildroot}%{_datadir}/ros-stacks/%{shortname}/laser_assembler/
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/laser_assembler/bin
for i in laser_scan_assembler laser_scan_assembler_srv merge_clouds point_cloud_assembler point_cloud_assembler_srv; do
  cp -a bin/$i %{buildroot}%{_bindir}
  ln -s %{_bindir}/$i %{buildroot}%{_datadir}/ros-stacks/%{shortname}/laser_assembler/bin/$i
done
mkdir -p %{buildroot}%{python_sitelib}
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/laser_assembler/src
for i in laser_assembler point_cloud_assembler; do
  cp -a src/$i %{buildroot}%{python_sitelib}/
  ln -s %{python_sitelib}/$i %{buildroot}%{_datadir}/ros-stacks/%{shortname}/laser_assembler/src/$i
done
popd  

#laser_filters
pushd laser_filters
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/laser_filters/bin
for i in generic_laser_filter_node scan_to_cloud_filter_chain scan_to_scan_filter_chain; do
  cp -a bin/$i %{buildroot}%{_bindir}
  ln -s %{_bindir}/$i %{buildroot}%{_datadir}/ros-stacks/%{shortname}/laser_filters/bin/$i
done
cp -a include *.dox *.xml doc %{buildroot}%{_datadir}/ros-stacks/%{shortname}/laser_filters/
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/laser_filters/lib
for i in liblaser_scan_filters.so libpointcloud_filters.so; do
  cp -a lib/$i %{buildroot}%{_libdir}
  ln -s %{_libdir}/$i %{buildroot}%{_datadir}/ros-stacks/%{shortname}/laser_filters/lib/$i
done
popd

#laser_geometry
pushd laser_geometry
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/laser_geometry
cp -a include *.dox *.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/laser_geometry/
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/laser_geometry/lib
cp -a lib/liblaser_geometry.so %{buildroot}%{_libdir}
ln -s %{_libdir}/liblaser_geometry.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/laser_geometry/lib/liblaser_geometry.so
popd

chrpath -d %{buildroot}%{_bindir}/* 
chrpath -d %{buildroot}%{_libdir}/*.so

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%{_bindir}/generic_laser_filter_node
%{_bindir}/laser_scan_assembler 
%{_bindir}/laser_scan_assembler_srv
%{_bindir}/merge_clouds
%{_bindir}/point_cloud_assembler
%{_bindir}/point_cloud_assembler_srv
%{_bindir}/scan_to_cloud_filter_chain
%{_bindir}/scan_to_scan_filter_chain
%{_datadir}/ros-stacks/%{shortname}/
%exclude %{_datadir}/ros-stacks/%{shortname}/laser_assembler/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/laser_filters/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/laser_geometry/include/
%{_libdir}/liblaser_geometry.so
%{_libdir}/liblaser_scan_filters.so
%{_libdir}/libpointcloud_filters.so
%{python_sitelib}/laser_assembler 
%{python_sitelib}/point_cloud_assembler

%files devel
%{_datadir}/ros-stacks/%{shortname}/laser_assembler/include/
%{_datadir}/ros-stacks/%{shortname}/laser_filters/include/
%{_datadir}/ros-stacks/%{shortname}/laser_geometry/include/

%changelog
* Fri Jun 1 2012 Tom Callaway <spot@fedoraproject.org> - 1.4.4-1
- initial package
